<?php 
use_helper('UrlFunctions'); 
use_helper('UtilFunctions'); 

$o_BalanceDiaNew = new BalanceDiaBean();
$o_BalanceDiaNew->setIdColaboradorPermitido($a_Colaborador); 
$o_BalanceDiaNew->setIdSucursal($Idsucursal); 


$o_BalanceDiaNewDP 		= new BalanceDiaDP($o_BalanceDiaNew);
$fechaBalanceAbierto  	= $o_BalanceDiaNewDP->ObtenerDiaAbierto();


$o_ArArqueoDetalleProductoFN = new ArArqueoDetalleProductoFN();
$o_ArArqueoDetalleProductoFN->setIdclase($idClase);
$o_ArArqueoDetalleProductoFN->setIdsucursal($Idsucursal);
$o_ArArqueoDetalleProductoFN->setIdmercado($Idmercado);
$o_ArArqueoDetalleProductoFN->setIdcolaborador($Idcolaborador);
$o_ArArqueoDetalleProductoFN->setFecha($fecha);
$o_ArArqueoDetalleProductoFN->sortCampos = "Fecharegistro";
$o_ArArqueoDetalleProductoFN->sortType   = "2";

$a_o_ArArqueoDetalleProductoBN = $o_ArArqueoDetalleProductoFN->select();


/*
echo "<pre>";
print_r($a_o_ArArqueoDetalleProductoBN);
echo "</pre>";
*/




$idClase = "PRODUCTO";

$a_ArClase = new ArClaseFN();
$a_claseFN = $a_ArClase->select();

//print_r($a_valorFN_B);

?>

<script>

deleteRegistro = function(id,codigo){
	//alert("---")
  	if(confirm("Esta seguro de eliminar el deposito?")){
      location.href="<?=buildUrl('arqueo/delete')?>"+codigo;
 	} 
}
function recarga(){
	window.location.reload();
}
</script>
<?php
//echo myUser::getUser()->getRoleId();
//error_reporting(E_ALL);
//ini_set('display_errors','On'); //PARA PRODUCCION "Off"


//print_r($a_o_ArArqueoDetalleProductoBN);


if(isset($control)){
	
  $o_ArArqueoCabeceraFN = new ArArqueoCabeceraFN();
  $o_ArArqueoCabeceraFN->setIdclase($idClase);
  $o_ArArqueoCabeceraFN->setIdsucursal($Idsucursal);
  $o_ArArqueoCabeceraFN->setIdmercado($Idmercado);
  $o_ArArqueoCabeceraFN->setIdcolaborador($Idcolaborador);
  $o_ArArqueoCabeceraFN->setFecha($fecha);
  $o_ArArqueoCabeceraBN = $o_ArArqueoCabeceraFN->selectByPK();
  
  if(is_object($o_ArArqueoCabeceraBN)){
  	
  	$o_ArArqueoDetalleProductoFN = new ArArqueoDetalleProductoFN();
	$o_ArArqueoDetalleProductoFN->setIdclase($idClase);
	$o_ArArqueoDetalleProductoFN->setIdsucursal($Idsucursal);
	$o_ArArqueoDetalleProductoFN->setIdmercado($Idmercado);
	$o_ArArqueoDetalleProductoFN->setIdcolaborador($Idcolaborador);
	$o_ArArqueoDetalleProductoFN->setFecha($fecha);
	$a_o_ArArqueoDetalleProductoFN = $o_ArArqueoDetalleProductoFN->select();
	
	/*echo "<pre>";
	print_r($a_o_ArArqueoDetalleProductoFN);
	echo "</pre>";
	*/
	if(is_array($a_o_ArArqueoDetalleProductoFN)){
		foreach ($a_o_ArArqueoDetalleProductoFN as $key => $o_ArArqueoDetalleProductoFN){
			$o_ArArqueoDetalleProductoDP = new ArArqueoDetalleProductoDP();
			$o_ArArqueoDetalleProductoDP->setIdclase($o_ArArqueoDetalleProductoFN->getIdclase());
			$o_ArArqueoDetalleProductoDP->setIdsucursal($o_ArArqueoDetalleProductoFN->getIdsucursal());
			$o_ArArqueoDetalleProductoDP->setIdmercado($o_ArArqueoDetalleProductoFN->getIdmercado());
			$o_ArArqueoDetalleProductoDP->setIdcolaborador($o_ArArqueoDetalleProductoFN->getIdcolaborador());
			$o_ArArqueoDetalleProductoDP->setFecha($o_ArArqueoDetalleProductoFN->getFecha());
			
			
			
			$o_ArArqueoDetalleProductoDP->setCantidad($o_ArArqueoDetalleProductoFN->getCantidad());
			
			$o_ArArqueoDetalleProductoDP->setSubtotal($o_ArArqueoDetalleProductoFN->getSubtotal());
			$o_ArArqueoDetalleProductoDP->setFecharegistro($o_ArArqueoDetalleProductoFN->getFecharegistro());
			$o_ArArqueoDetalleProductoDP->setUsuarioregistro($o_ArArqueoDetalleProductoFN->getUsuarioregistro());
			
			$o_ArArqueoDetalleProductoDP->savelog();
		}

	}
  	
	
	if(is_array($a_o_ArArqueoDetalleProductoBN)){
		foreach ($a_o_ArArqueoDetalleProductoBN as $key => $o_ArArqueoDetalleProductoBN){
			$subtotal += $o_ArArqueoDetalleProductoBN->getSubtotal();
			//Aplicar los pagos a cada prestamo y actualizar saldo
			$id_pago_update ="";
			$MontoPago = $o_ArArqueoDetalleProductoBN->getSubtotal();
			$idPrestamo = $o_ArArqueoDetalleProductoBN->getIdprestamo();
			$idCliente = $o_ArArqueoDetalleProductoBN->getIdcliente();
			$fecha = $fechaBalanceAbierto;
			if($MontoPago == "0"){
				//Preguntar si esta registrado en ese dia un Pago
				$o_PagoBean = new PagoBean();
				$o_PagoBean->setIdPrestamo($idPrestamo);
				$o_PagoBean->setFechaPago($fecha);
				$o_PagoBL = new PagoBL();
				$a_o_pago = $o_PagoBL->busquedaPago($o_PagoBean);
				if(is_array($a_o_pago) && count($a_o_pago)){
					$permtir_reg_pago = "0";
				}else{
					$permtir_reg_pago = "1";
				}
			}else{
				$permtir_reg_pago = "1";
				$o_PagoBean = new PagoBean();
				$o_PagoBean->setIdPrestamo($idPrestamo);
				$o_PagoBean->setFechaPago($fecha);
				$o_PagoBL = new PagoBL();
				$a_o_pago = $o_PagoBL->busquedaPago($o_PagoBean);
				
				if(is_array($a_o_pago) && count($a_o_pago)){//Update del Pago
					foreach ($a_o_pago as $key => $o_pago) {
						if($o_pago->getMontoPago()== 0){
							$id_pago_update = $o_pago->getIdPago();
						}
					}
				}
			}
			if($permtir_reg_pago){
			    $MontoPago = abs($MontoPago);
				$o_PagoBean = new PagoBean();
				$o_PagoBean->setIdPrestamo($idPrestamo);
				$o_PagoBean->setMontoPago($MontoPago);
				$o_PagoBean->setFechaPago($fecha);
				$o_PagoBean->setUsuarioCreacion(myUser::getUser()->getUserId());
				$o_PagoBean->setIdColaborador(myUser::getUser()->getIdColaborador());
				$o_PagoBean->setFechaCreacion(date('Y-m-d H:i:s'));
				$o_PagoBean->setTiporeferencia($idClase);
				$o_PagoBL = new PagoBL();
				if($id_pago_update){
					$o_PagoBean->setIdPago($id_pago_update);
					$o_PagoBL->modificarPago($o_PagoBean);
					$idPago = $id_pago_update;
				}else{
					$idPago = $o_PagoBL->insertarPago($o_PagoBean);
				}
				
				//Actualizar el Saldo del Prestamo-----------------------
				
				$o_PrestamoBeanTemp = new PrestamoBean();
				$o_PrestamoBeanTemp->setIdPrestamo($idPrestamo);
				//$o_PrestamoBLTemp = new PrestamoBL();
				$o_PrestamoDP = new PrestamoDP($o_PrestamoBeanTemp);
			    $a_o_Prestamo = $o_PrestamoDP->select();
				foreach ($a_o_Prestamo as $key =>$o_Prestamo){
					$SaldoAnterior = $o_Prestamo->getSaldoPrestamo();
				}
				$o_PrestamoBean = new PrestamoBean();
				$o_PrestamoBean->setIdPrestamo($idPrestamo);
				$NuevoSaldo = $SaldoAnterior - $MontoPago;
				
				if($NuevoSaldo == 0){
					$o_PrestamoBean->setSaldoPrestamo("0.00");
					$o_PrestamoBean->setEstado("C");
					$o_PrestamoBean->setFechaCancelacion(date('Y-m-d H:i:s'));
					//Enviar correo
					
				}elseif($NuevoSaldo < 0){//Se cancelo con un monto mayor
					$NuevoSaldo = "0";
					$o_PrestamoBean->setSaldoPrestamo("0.00");
					$o_PrestamoBean->setEstado("C");
					$o_PrestamoBean->setFechaCancelacion(date('Y-m-d H:i:s'));
					//Enviar correo
										
					
				}else{//Descuento de saldo Normal
					$o_PrestamoBean->setSaldoPrestamo($NuevoSaldo);	
				}
				$o_PrestamoBL = new PrestamoBL();
				$o_PrestamoBL->modificarPrestamo($o_PrestamoBean);
			}
			//Actualizar cada registro con el pago
			$o_ArArqueoDetalleProductoDP = new ArArqueoDetalleProductoDP();
			$o_ArArqueoDetalleProductoDP->setIdclase($idClase);
			$o_ArArqueoDetalleProductoDP->setIdsucursal($IdSucursal);
			$o_ArArqueoDetalleProductoDP->setIdmercado($IdMercado);
			$o_ArArqueoDetalleProductoDP->setIdcolaborador($idColaborador);
			$o_ArArqueoDetalleProductoDP->setFecha($fechaBalanceAbierto);
			$o_ArArqueoDetalleProductoDP->setIdprestamo($idPrestamo);
			$o_ArArqueoDetalleProductoDP->setIdcliente($idCliente);
			$o_ArArqueoDetalleProductoDP->setIdpagoreferencia($idPago);
			$o_ArArqueoDetalleProductoDP->setEstado("C");
			$o_ArArqueoDetalleProductoDP->update();
			
			//Fin de Aplicar los pagos a cada prestamo y actualizar saldo
		}
		
	}
	
	$o_ArArqueoCabeceraDP = new ArArqueoCabeceraDP();
	$o_ArArqueoCabeceraDP->setIdclase($idClase);
	$o_ArArqueoCabeceraDP->setIdsucursal($IdSucursal);
	$o_ArArqueoCabeceraDP->setIdmercado($IdMercado);
	$o_ArArqueoCabeceraDP->setIdcolaborador($idColaborador);
	$o_ArArqueoCabeceraDP->setFecha($fechaBalanceAbierto);
	$o_ArArqueoCabeceraDP->setTotal($subtotal);
	$o_ArArqueoCabeceraDP->setEstado("C");
	$o_ArArqueoCabeceraDP->setFechacierre(date("Y-m-d H:i:s"));
	$bResult = $o_ArArqueoCabeceraDP->update();
	
	
	
  	
  }
  
  if(1)
    {
        if( $typeSubmit == "next" )
        {
            ?>
            <script language="JavaScript">
            location.href = "<?php echo buildUrl( 'arqueo/addProducto', "" ) ?>";
            </script>
            <?
        }
        else 
        {
            ?>
            <script language="JavaScript">
            location.href = "<?php echo buildUrl( 'arqueo/addProducto', "" ) ?>";
            </script>
            <?
        }
    }
    else
    {
        //$url = buildUrl('cli/add', "block=".$block."&error=1");
        echo '<div class="ui-widget" style="margin: 2px;"><div class="ui-state-error ui-corner-all" style="padding: 0 .7em;"><p><span class="ui-icon ui-icon-alert" style="float: left; margin-right: .3em;"></span><strong>Error:</strong>Error en actualizar el cliente.</p></div></div>';
    }
}


//if(is_array($a_ObjectBean)){
if(1){
  //while(list($key,$o_ObjectBean) = each($a_ObjectBean)){
  	
  	
  	
	
?>
<table class="cuerpo" width="100%" border="0" cellpadding="0" cellspacing="0">
	
	<tr>
		<td valign="top">
			 
				
			  
                        <?php
                        $s_Param = '';
                        if( isset( $id ) )
                        {
                            $s_Param = 'id='.$id;
                        }
                        ?>
			  
                        <table id="tabShowScan" cellpadding="0" cellspacing="0" class="" style="margin-top: 5px;">
                            <tr>
                              <?php 
                              foreach ($a_claseFN as $ky => $o_claseFN){
                              	if($o_claseFN->getIdclase() == $idClase){
                              		$classIzq = "mnuActivoIzq";
                              		$classTxt = "mnuActivoTxt";
                              		$classDer = "mnuActivoDer";
                              	
	                              ?>	
	                              <td class="<?php echo $classIzq;?>" type='maintTabguiaGeneral'><img src="/images/common/spacer.gif" width="7"></td>
	                              <td class="<?php echo $classTxt;?>" type='maintTabguiaGeneral' nowrap <?php if($o_claseFN->getIdclase() == $idClase){?> onclick="location.href='<?php echo buildUrl('arqueo/add'.ucwords(strtolower($o_claseFN->getIdclase())), $s_Param) ?>';" <?php } ?>><?php echo $o_claseFN->getDescripcion();?></td>
	                              <td class="<?php echo $classDer;?>" type='maintTabguiaGeneral'><img src="/images/common/spacer.gif" width="8"></td>
	                              <td><img src="/images/common/spacer.gif"></td>
                              
                             
                              <?php } 
                              }?>
                            </tr>
                        </table>
			  
                        <table width="100%" cellspacing="2" cellpadding="2" border="0" class="marco marcoForm">
                            <tr>
                                <td nowrap="nowrap">
                                    									
									<table border="0" cellpadding="0" cellspacing="0" width="100%">
										<tr>
										  <td class="titleBody"><li>&nbsp;&nbsp;Productos</li></td>
										  <td align="right" valign="baseline">
										   
										  </td>
										</tr>
									</table>
									
									<table class="marco" border="0" cellpadding="0" cellspacing="0" width="100%">
								        <tr>
								          <td>
								            <table class="grid" width="100%" border="0" cellpadding="0" cellspacing="0">
								              <tr height="23">
												<th width="2%" >Nro</th>
								                <th width="4%" >C.Cli.</th>
								                <th width="4%" >C.Prest.</th>
								               
								                <th width="12%" align="left">Tipo.Producto</th>
								                <th width="14%" align="left">Producto</th>
								                <th width="18%" align="left" >Cliente</th>
											    <th width="3%" align="center">Cant.</th>
											    <th width="4%" align="right">P.Unitario</th>
											    <th width="4%" align="right">Monto</th>
											   
											    
												<th width="4%" align="center">Estado</th>
								                <th width="5%" id="col01" onMouseOver="sort_col(this);" >Usr.Crea.</th>
								                <th width="10%" id="col01" onMouseOver="sort_col(this);" >Fec.Crea.</th>
								              
								                <th width="7%">&nbsp;</th>
								              </tr>
								              <? if(count($a_o_ArArqueoDetalleProductoBN)>0){ ?>
								              <? foreach ($a_o_ArArqueoDetalleProductoBN as $iKey => $o_objBean){    	?>
								              <tr onClick="TR_click(this);">
									               <td class="chk"><?=($tamanioPag)*($page-1)+($iKey+1)?></td>
									               <td align="center"><?=$o_objBean->getIdcliente()?></td>
									               <td align="center"><?=$o_objBean->getIdprestamo()?></td>
									               <td align="left"><?=$o_objBean->getDescripciontipoproducto()?></td>
									               <td align="left"><?=$o_objBean->getDecripcionproducto()?></td>
									                <td align="left"><?=ucwords(strtolower($o_objBean->getNombrecliente()))?></td>
									                							                
									                <td align="center"><?php echo $o_objBean->getCantidad();?></td>
									                <td align="right"><?php echo $o_objBean->getPreciounitario();?></td>
									                <td align="right"><?=number_format($o_objBean->getSubtotal(),2);$subtotal += $o_objBean->getSubtotal();
									                 $id_key = "Idclase=".$o_objBean->getIdclase()."&Idsucursal=".$o_objBean->getIdsucursal()."&Idmercado=".$o_objBean->getIdmercado()."&Idcolaborador=".$o_objBean->getIdcolaborador()."&fecha=".$o_objBean->getFecha()."&Idcolaborador=".$o_objBean->getIdcolaborador()."&Idcliente=".$o_objBean->getIdcliente()."&Idprestamo=".$o_objBean->getIdprestamo()."&correlativo=".$o_objBean->getCorrelativo();?></td>
									                
									                
									                
									                <td align="center"><?if($o_objBean->getEstado()=='P'){ echo "Pendiente"; } else {echo "Cerrado";} ?></td>
													<td align="center"><?=strtoupper($o_objBean->getUsuarioregistro())?></td>
									                <td align="center"><?=$o_objBean->getFecharegistro()?></td>
								                	<td align="center" valign="top">
								                   		<img src="/images/common/buttons/btnEdit.gif" title="Mostrar" style="cursor:pointer;" onclick="objMainTab.modalDialog('<?=buildUrl('arqueo/editProductoDetalle',$id_key);?>',{title:'',width:510,height:380})">&nbsp;
								                   
												    <? if(myUser::getUser()->getRoleId() == "sys.gen"){?>
								                   		<input type="image" title="Eliminar" src="/images/common/buttons/btnDelete.gif" onclick="deleteRegistro('<?=$id_key?>','<?=str_replace("=","/",str_replace("&","/",$id_key."&deleteproducto=1"))?>')">;
								                   <? }?>
								                  
								                </td>
								              </tr>
								              <? } ?>
								              <? }else{ ?>
								              <tr>
								                <td colspan="7" align="center">No se produjo resultado</td>
								              </tr>
								              <? } ?>
								               <tr>
		                                			<td align="right" width="84%" colspan="8">Total</td>
		                                			<td align="right" width="10%"><div style="Font-weight:bold" class="label" id="totalEfectivo"><?php echo number_format($subtotal,2);?></label></td>
		                                			<td align="right" width="6%">&nbsp;</td>
		                                		</tr>
								            </table>
								          </td>
								        </tr>
								       
                                	

								      </table>
                                	
                                		                                    	
                                    	                
                                    
                                	
                                </td>
                            </tr>
                        </table>
                        
                        
                        
                        
				<table hspace="2px" width="96%" cellpadding="0" cellspacing="0">
					<tr>
						<td valign="top" colspan="2">
                            
                            <table style="pad">
                            </table>
					
								<table width="100%" border="0" cellpadding="0" cellspacing="0" style="background: #fff">
									<tr>
										<td height="0" width="100%">
										   

											   <table width="100%" border="0" cellspacing="0" cellpadding="0">
													<tr>
														<td><img src="/images/common/spacer.gif" width="10"></td>
													</tr>
													<tr>
													    <td align="center">
															<input type="hidden" name="typeSubmit" id="typeSubmit">
															<!--<input class="button" type="submit" value="Grabar" onclick="$('typeSubmit').value='next';">-->
															<!--<input class="button" type="button" value="Siguiente" onclick="location.href='<?php echo buildUrl('cli/datEval', $s_Param) ?>'"/>-->
															<input class="button" type="button" value="Cancelar" onclick=" parent.objMainTab.windowsCloseAll();"/>
													    </td>
													</tr>
													<tr>
														<td height="10">&nbsp;</td>
													</tr>
												</table>
											
										</td>
									</tr>
								</table>							
								
						</td>
					</tr>
				</table> 
			
		</td>
	</tr>
</table>


<?php

}
?>

